#include <iostream>
#include <vector>
#include <map>
#include <set>
#include <algorithm>

using namespace std;
using ll = long long;
using ld = long double;

struct FenwickTree {
    int n{};
    vector<int> data{};

    FenwickTree(int n) : n(n) {
        data.assign(n, 0);
    }

    void add(int index, int value) {
        for (int i = index; i < n; i |= (i + 1)) {
            data[i] += value;
        }
    }

    int get(int r) {
        if (r <= 0) {
            return 0;
        }

        int result = 0;

        for (int i = r - 1; i >= 0; i = (i & (i + 1)) - 1) {
            result += data[i];
        }

        return result;
    }

    int get(int l, int r) {
        return get(r) - get(l);
    }
};

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    // FenwickTree ft(10);

    // while (true) {
    //     int type;
    //     cin >> type;

    //     if (type == 0) {
    //         int index, value;
    //         cin >> index >> value;

    //         ft.add(index, value);
    //     } else if (type == 1) {
    //         int r;
    //         cin >> r;

    //         cout << ft.get(r) << "\n";
    //     }
    // }

    int n;
    cin >> n;

    vector<int> cows(n);
    vector<int> prev(n);
    vector<int> prev_by_type(n + 1, -1);

    for (int i = 0; i < n; i++) {
        int cow;
        cin >> cow;

        cows[i] = cow;
        prev[i] = prev_by_type[cow];
        prev_by_type[cow] = i;
    }

    FenwickTree is_first(n);
    ll result = 0;

    for (int r = 0; r < n; r++) {
        is_first.add(r, 1);

        if (prev[r] >= 0) {
            is_first.add(prev[r], -1);
        }

        // cout << r + 1 << " " << is_first.get(prev[r] + 1, r) << "\n";

        result += (ll)is_first.get(prev[r] + 1, r);
    }

    cout << result << "\n";

    return 0;
}
