#include <iostream>
#include <vector>
#include <map>
#include <set>
#include <algorithm>

using namespace std;
using ll = long long;
using ld = long double;

const int mod = 1000000007;

struct SegmentTree {
    int size{};
    vector<int> data{};

    SegmentTree(int size) : size(size) {
        data.assign(size * 4, 0);
    }

    void clear() {
        data.assign(size * 4, 0);
    }

    void update(int index, int value) {
        do_update(0, 0, size, index, value);
    }

    void do_update(int node, int low, int high, int index, int value) {
        if (low == index && low == high - 1) {
            data[node] = value;
            return;
        }

        int middle = (low + high) / 2;

        if (index >= middle) {
            do_update(node * 2 + 2, middle, high, index, value);
        } else {
            do_update(node * 2 + 1, low, middle, index, value);
        }

        data[node] = (data[node * 2 + 1] + data[node * 2 + 2]) % mod;
    }

    int get(int low, int high) {
        return do_get(0, 0, size, low, high);
    }

    int do_get(int node, int low, int high, int query_low, int query_high) {
        if (low == query_low && high == query_high) {
            return data[node];
        }

        if (query_high <= low || query_low >= high) {
            return 0;
        }

        int middle = (low + high) / 2;

        int left_result = do_get(node * 2 + 1, low, middle, query_low, min(query_high, middle));
        int right_result = do_get(node * 2 + 2, middle, high, max(query_low, middle), query_high);

        return (left_result + right_result) % mod;
    }
};

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int n;
    cin >> n;

    if (n <= 1) {
        cout << "1\n";
        return 0;
    }

    vector<int> max_hunger(n);

    for (auto& value : max_hunger) {
        cin >> value;
    }

    vector<vector<SegmentTree>> dp(1001, vector(2, SegmentTree(1001)));

    for (int cap = 1000; cap >= 0; cap--) {
        for (int j = 0; j <= max_hunger[0] - cap; j++) {
            dp[cap][0].update(j, 1);
        }

        for (int j = 0; j <= min(max_hunger[1], max_hunger[0]) - cap; j++) {
            dp[cap][1].update(j, 1);
        }

        for (int i = 2; i < n; i++) {
            for (int j = 0; j <= max_hunger[i] - cap; j++) {
                dp[cap][i % 2].update(j, dp[cap][(i + 1) % 2].get(0, max_hunger[i - 1] - cap - j + 1));
            }
        }
    }

    if (n % 2 == 0) {
        int result = dp[0][(n + 1) % 2].get(0, max_hunger[n - 1] + 1);
        cout << result << "\n";
    } else if (n % 2 == 1) {
        int result = 0;

        for (int cap = 0; cap <= 1000; cap++) {
            result += dp[cap][(n + 1) % 2].get(0, max_hunger[n - 1] - cap + 1);
        }

        cout << result << "\n";
    }

    return 0;
}