#include <iostream>
#include <vector>
#include <map>
#include <set>
#include <algorithm>
#include <limits>

using namespace std;
using ll = long long;
using ld = long double;

const int infinity = numeric_limits<int>::max() / 4;

struct SegmentTree {
    int size{};
    vector<int> data{};

    SegmentTree(int size) : size(size) {
        data.assign(size * 4, infinity);
    }

    void update(int index, int value) {
        do_update(0, 0, size, index, value);
    }

    void do_update(int node, int low, int high, int index, int value) {
        if (low == index && low == high - 1) {
            data[node] = value;
            return;
        }

        int middle = (low + high) / 2;

        if (index >= middle) {
            do_update(node * 2 + 2, middle, high, index, value);
        } else {
            do_update(node * 2 + 1, low, middle, index, value);
        }

        data[node] = min(data[node * 2 + 1], data[node * 2 + 2]);
    }

    int get(int low, int high) {
        return do_get(0, 0, size, low, high);
    }

    int do_get(int node, int low, int high, int query_low, int query_high) {
        if (low == query_low && high == query_high) {
            return data[node];
        }

        if (query_high <= low || query_low >= high) {
            return infinity;
        }

        int middle = (low + high) / 2;

        int left_result = do_get(node * 2 + 1, low, middle, query_low, min(query_high, middle));
        int right_result = do_get(node * 2 + 2, middle, high, max(query_low, middle), query_high);

        return min(left_result, right_result);
    }
};

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int n, k;
    cin >> n >> k;

    vector<int> deltas(n + 1);
    deltas[0] = 0;

    for (int i = 1; i <= n; i++) {
        char c;
        cin >> c;

        deltas[i] = deltas[i - 1] + (c == 'G' ? 1 : -1);
    }

    vector<int> dp(n + 1);
    vector<multiset<int>> dp_values_by_delta(n * 2 + 1, multiset<int>{});
    SegmentTree tree(n * 2 + 1);

    dp[0] = 0;
    dp_values_by_delta[n].insert(0);
    tree.update(n, 0);

    for (int i = 1; i <= n; i++) {
        // cout << i << endl;
        int delta = deltas[i];

        dp[i] = min(
            tree.get(0, delta + n + 1) + 1,
            tree.get(delta + n + 1, n * 2)
        );
        
        auto& delta_values = dp_values_by_delta[delta + n];

        delta_values.insert(dp[i]);
        tree.update(delta + n, *delta_values.begin());

        if (i >= k) {
            int prev_delta = deltas[i - k];
            auto& prev_delta_values = dp_values_by_delta[prev_delta + n];
            // cout << "here " << i << " " << (i - k) << " " << prev_delta << " " << dp[i - k] << endl;

            prev_delta_values.erase(prev_delta_values.find(dp[i - k]));
            tree.update(prev_delta + n, prev_delta_values.size() == 0 ? infinity : (*prev_delta_values.begin()));
        }
    }

    cout << dp[n] << "\n";

    return 0;
}
